@@ -39,6 +39,8 @@
 #include "gedit-view.h"
 #include "gedit2.h"
 
+#include "gnome-print-font-picker.h"
+
 /* To be syncronized with gedit-preferences.glade2 */
 #define LOGO			6
 #define	TOOLBAR_SETTINGS  	0
@@ -51,6 +53,7 @@
 #define WRAP_MODE_SETTINGS	8
 #define PRINT_SETTINGS		9
 #define LINE_NUMBERS_SETTINGS	10
+#define PRINT_FONTS_SETTINGS	11
 
 /*
 #define DEBUG_MDI_PREFS
@@ -71,9 +74,9 @@ struct _GeditPreferencesDialogPrivate
 
 	GtkTreeModel *categories_tree_model;
 
+#if 0
 	/* Toolbar page */
-	GtkWidget	*toolbar_show_radiobutton;
-	GtkWidget	*toolbar_hide_radiobutton;
+	GtkWidget	*toolbar_show_checkbutton;
 	
 	GtkWidget	*toolbar_button_frame;
 	GtkWidget	*toolbar_system_radiobutton;
@@ -83,10 +86,10 @@ struct _GeditPreferencesDialogPrivate
 	GtkWidget	*toolbar_tooltips_checkbutton;
 
 	/* Statusbar page */
-	GtkWidget	*statusbar_show_radiobutton;
-	GtkWidget	*statusbar_hide_radiobutton;
+	GtkWidget	*statusbar_show_checkbutton;
 	GtkWidget	*statusbar_cursor_position_checkbutton;
 	GtkWidget	*statusbar_overwrite_mode_checkbutton;
+#endif
 
 #ifdef DEBUG_MDI_PREFS	
 	/*MDI page */
@@ -135,6 +138,11 @@ struct _GeditPreferencesDialogPrivate
 	/* Line numbers page */
 	GtkWidget	*display_line_numbers_checkbutton;
 
+	/* Print/Fonts page */
+	GtkWidget	*body_fontpicker;
+	GtkWidget	*headers_fontpicker;
+	GtkWidget	*numbers_fontpicker;
+	GtkWidget	*restore_default_fonts_button;
 };
 
 typedef struct _CategoriesTreeItem	CategoriesTreeItem;
@@ -162,11 +170,14 @@ static GtkTreeModel* gedit_preferences_dialog_create_categories_tree_model ();
 
 static void gedit_preferences_dialog_categories_tree_selection_cb (GtkTreeSelection *selection, 
 							GeditPreferencesDialog *dlg);
-
+#if 0
 static gboolean gedit_preferences_dialog_setup_toolbar_page (GeditPreferencesDialog *dlg, GladeXML *gui);
-static void gedit_preferences_dialog_toolbar_show_radiobutton_toggled (GtkToggleButton *show_button,
+static void gedit_preferences_dialog_toolbar_show_checkbutton_toggled (GtkToggleButton *show_button,
 							 GeditPreferencesDialog *dlg);
 static gboolean gedit_preferences_dialog_setup_statusbar_page (GeditPreferencesDialog *dlg, GladeXML *gui);
+static void gedit_preferences_dialog_statusbar_show_checkbutton_toggled (GtkToggleButton *show_button,
+							 GeditPreferencesDialog *dlg);
+#endif
 
 #ifdef DEBUG_MDI_PREFS
 static gboolean gedit_preferences_dialog_setup_mdi_page (GeditPreferencesDialog *dlg, GladeXML *gui);
@@ -182,16 +193,29 @@ static void gedit_preferences_dialog_undo_checkbutton_toggled (GtkToggleButton *
 static gboolean gedit_preferences_dialog_setup_tabs_page (GeditPreferencesDialog *dlg, GladeXML *gui);
 static gboolean gedit_preferences_dialog_setup_logo_page (GeditPreferencesDialog *dlg, GladeXML *gui);
 static gboolean gedit_preferences_dialog_setup_wrap_mode_page (GeditPreferencesDialog *dlg, GladeXML *gui);
+static void gedit_preferences_dialog_auto_save_checkbutton_toggled (GtkToggleButton *button,
+							 GeditPreferencesDialog *dlg);
 static gboolean gedit_preferences_dialog_setup_save_page (GeditPreferencesDialog *dlg, GladeXML *gui);
 static void gedit_preferences_dialog_line_numbers_checkbutton_toggled (GtkToggleButton *button,
 							 GeditPreferencesDialog *dlg);
 static gboolean gedit_preferences_dialog_setup_page_page (GeditPreferencesDialog *dlg, GladeXML *gui);
 static gboolean gedit_preferences_dialog_setup_line_numbers_page (GeditPreferencesDialog *dlg, 
 							          GladeXML *gui);
+static gboolean gedit_preferences_dialog_setup_print_fonts_page (GeditPreferencesDialog *dlg, 
+								 GladeXML *gui);
+static void gedit_preferences_dialog_print_font_restore_default_button_clicked (
+								GtkButton *button, 
+								GeditPreferencesDialog *dlg);
+static gboolean gedit_preferences_dialog_selection_init (GtkTreeModel *model, 
+							 GtkTreePath *path, 
+							 GtkTreeIter *iter, 
+							 GeditPreferencesDialog *dlg);
+static void gedit_preferences_dialog_categories_tree_realize (GtkWidget		     *widget, 
+						  	      GeditPreferencesDialog *dlg);
 
-
+static gint last_selected_page_num = FONT_COLORS_SETTINGS;
 static GtkDialogClass* parent_class = NULL;
-
+#if 0
 static CategoriesTreeItem user_interface [] =
 {
 	{_("Toolbar"), NULL, TOOLBAR_SETTINGS},
@@ -203,6 +227,7 @@ static CategoriesTreeItem user_interface [] =
 
 	{ NULL }
 };
+#endif
 
 static CategoriesTreeItem editor_behavior [] =
 {
@@ -223,6 +248,8 @@ static CategoriesTreeItem print [] =
 {
 	{_("Page"), NULL, PRINT_SETTINGS},
 
+	{_("Fonts"), NULL, PRINT_FONTS_SETTINGS},
+
 	{ NULL }
 };
 
@@ -230,7 +257,9 @@ static CategoriesTreeItem toplevel [] =
 {
 	{_("Editor"), editor_behavior, LOGO},
 	{_("Print"), print, LOGO},
+#if 0
 	{_("User interface"), user_interface, LOGO},
+#endif
 	{ NULL }
 };
 
@@ -281,14 +310,30 @@ gedit_preferences_dialog_init (GeditPreferencesDialog *dlg)
 	GtkWidget *hbox;
 	GtkWidget *r;
        	GtkWidget *l;
+	GtkWidget *ct;
+	GtkWidget *label;
 	
 	gedit_debug (DEBUG_PREFS, "");
 
 	dlg->priv = g_new0 (GeditPreferencesDialogPrivate, 1);
 
+	gedit_preferences_dialog_add_buttons (dlg);	
+	
 	hbox = gtk_hbox_new (FALSE, 12);
+	
 	gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
-	r = gedit_preferences_dialog_create_categories_tree (dlg);
+	
+	r = gtk_vbox_new (FALSE, 0);
+	
+	label = gtk_label_new_with_mnemonic (_("Cat_egories:"));
+	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
+	g_object_set (G_OBJECT (label), "xalign", 0.0, NULL);
+
+	ct = gedit_preferences_dialog_create_categories_tree (dlg);
+		
+	gtk_box_pack_start (GTK_BOX (r), label, FALSE, FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (r), ct, TRUE, TRUE, 0);
+
 	l = gedit_preferences_dialog_create_notebook (dlg);
 
 	gtk_box_pack_start (GTK_BOX (hbox), r, FALSE, FALSE, 0);
@@ -297,11 +342,11 @@ gedit_preferences_dialog_init (GeditPreferencesDialog *dlg)
 
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox), hbox,
 			FALSE, FALSE, 0);
+	
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), dlg->priv->categories_tree);
 
-	gtk_widget_show_all (hbox);
-
-	gedit_preferences_dialog_add_buttons (dlg);	
-
+	gtk_widget_show_all (GTK_DIALOG (dlg)->vbox);	
+	
 	gtk_window_set_modal (GTK_WINDOW (dlg), TRUE);
 
 	gtk_window_set_title (GTK_WINDOW (dlg), _("Preferences"));
@@ -397,7 +442,7 @@ gedit_preferences_dialog_create_categories_tree_model ()
 		}
       
 		category++;
-	}
+	}	
 
 	gedit_debug (DEBUG_PREFS, "Done");
 
@@ -406,11 +451,11 @@ gedit_preferences_dialog_create_categories_tree_model ()
 }
 
 static void
-gedit_preferences_dialog_categories_tree_selection_cb (GtkTreeSelection *selection, GeditPreferencesDialog *dlg)
+gedit_preferences_dialog_categories_tree_selection_cb (GtkTreeSelection *selection, 
+		GeditPreferencesDialog *dlg)
 {
  	GtkTreeIter iter;
 	GValue value = {0, };
-	gint page_num;
 
 	gedit_debug (DEBUG_PREFS, "");
 
@@ -421,14 +466,65 @@ gedit_preferences_dialog_categories_tree_selection_cb (GtkTreeSelection *selecti
 			    PAGE_NUM_COLUMN,
 			    &value);
 
-	page_num = g_value_get_int (&value);
+	last_selected_page_num = g_value_get_int (&value);
 
 	if (dlg->priv->notebook != NULL)
-		gtk_notebook_set_current_page (GTK_NOTEBOOK (dlg->priv->notebook), page_num);
+		gtk_notebook_set_current_page (GTK_NOTEBOOK (dlg->priv->notebook), 
+					       last_selected_page_num);
       	
 	g_value_unset (&value);
 }
 
+static gboolean 
+gedit_preferences_dialog_selection_init (
+		GtkTreeModel *model, 
+		GtkTreePath *path, 
+		GtkTreeIter *iter, 
+		GeditPreferencesDialog *dlg)
+{
+	GValue value = {0, };
+	gint page_num;
+
+	gedit_debug (DEBUG_PREFS, "");
+
+	gtk_tree_model_get_value (dlg->priv->categories_tree_model, iter,
+			    PAGE_NUM_COLUMN,
+			    &value);
+
+	page_num = g_value_get_int (&value);
+
+	g_value_unset (&value);
+
+	if (page_num == last_selected_page_num)
+	{
+		GtkTreeSelection *selection;
+
+		selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (dlg->priv->categories_tree));
+		g_return_val_if_fail (selection != NULL, TRUE);
+
+		gtk_tree_selection_select_iter (selection, iter);
+
+		g_return_val_if_fail (dlg->priv->notebook != NULL, TRUE);
+		gtk_notebook_set_current_page (GTK_NOTEBOOK (dlg->priv->notebook), page_num);
+    	
+		return TRUE;
+	}
+
+	return FALSE;
+}
+
+static void
+gedit_preferences_dialog_categories_tree_realize (GtkWidget		 *widget, 
+						  GeditPreferencesDialog *dlg)
+{
+	gedit_debug (DEBUG_PREFS, "");
+
+	gtk_tree_view_expand_all (GTK_TREE_VIEW (widget));
+
+	gtk_tree_model_foreach (dlg->priv->categories_tree_model, 
+			(GtkTreeModelForeachFunc) gedit_preferences_dialog_selection_init,
+			(gpointer)dlg);
+}
 
 static GtkWidget*
 gedit_preferences_dialog_create_categories_tree (GeditPreferencesDialog *dlg)
@@ -455,10 +551,13 @@ gedit_preferences_dialog_create_categories_tree (GeditPreferencesDialog *dlg)
 	model = gedit_preferences_dialog_create_categories_tree_model ();
 	
 	treeview = gtk_tree_view_new_with_model (model);
-/*
-	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (treeview), TRUE);
-*/
+	
+	dlg->priv->categories_tree = treeview;
+	dlg->priv->categories_tree_model = model;
+
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (treeview));
+	g_return_val_if_fail (selection != NULL, NULL);
+
 	gtk_tree_selection_set_mode (selection,
 				   GTK_SELECTION_SINGLE);
 
@@ -476,16 +575,17 @@ gedit_preferences_dialog_create_categories_tree (GeditPreferencesDialog *dlg)
   	gtk_tree_view_column_set_clickable (GTK_TREE_VIEW_COLUMN (column), FALSE);
 
 	g_signal_connect (selection, "changed", 
-			G_CALLBACK (gedit_preferences_dialog_categories_tree_selection_cb), dlg);
+			  G_CALLBACK (gedit_preferences_dialog_categories_tree_selection_cb), 
+			  dlg);
 
 	gtk_container_add (GTK_CONTAINER (sw), treeview);
 
       	g_signal_connect (G_OBJECT (treeview), "realize", 
-			G_CALLBACK (gtk_tree_view_expand_all), NULL);
+			  G_CALLBACK (gedit_preferences_dialog_categories_tree_realize), 
+			  dlg);
 
-	dlg->priv->categories_tree = treeview;
-	dlg->priv->categories_tree_model = model;
-	
+	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (treeview), FALSE);
+		
 	return sw;
 }
 
@@ -512,9 +612,10 @@ gedit_preferences_dialog_create_notebook (GeditPreferencesDialog *dlg)
 		    ("Could not find the required widgets inside gedit-preferences.glade2.\n");
 		return NULL;
 	}
-
+#if 0
 	gedit_preferences_dialog_setup_toolbar_page (dlg, gui);
 	gedit_preferences_dialog_setup_statusbar_page (dlg, gui);
+#endif
 #ifdef DEBUG_MDI_PREFS
 	gedit_preferences_dialog_setup_mdi_page (dlg, gui);
 #endif
@@ -526,6 +627,7 @@ gedit_preferences_dialog_create_notebook (GeditPreferencesDialog *dlg)
 	gedit_preferences_dialog_setup_save_page (dlg, gui);
 	gedit_preferences_dialog_setup_page_page (dlg, gui);
 	gedit_preferences_dialog_setup_line_numbers_page (dlg, gui);
+	gedit_preferences_dialog_setup_print_fonts_page (dlg, gui);
 
 	gtk_notebook_set_current_page (GTK_NOTEBOOK (dlg->priv->notebook), LOGO);
 	
@@ -548,14 +650,13 @@ gedit_preferences_dialog_new (GtkWindow *parent)
 	
 	return dlg;
 }
-
+#if 0
 static gboolean 
 gedit_preferences_dialog_setup_toolbar_page (GeditPreferencesDialog *dlg, GladeXML *gui)
 {
 	gedit_debug (DEBUG_PREFS, "");
 
-	dlg->priv->toolbar_show_radiobutton = glade_xml_get_widget (gui, "toolbar_show_radiobutton");
-	dlg->priv->toolbar_hide_radiobutton = glade_xml_get_widget (gui, "toolbar_hide_radiobutton");
+	dlg->priv->toolbar_show_checkbutton = glade_xml_get_widget (gui, "toolbar_show_checkbutton");
 	
 	dlg->priv->toolbar_button_frame = glade_xml_get_widget (gui, "toolbar_button_frame");
 	dlg->priv->toolbar_system_radiobutton = glade_xml_get_widget (gui, "toolbar_system_radiobutton");
@@ -564,8 +665,7 @@ gedit_preferences_dialog_setup_toolbar_page (GeditPreferencesDialog *dlg, GladeX
 	
 	dlg->priv->toolbar_tooltips_checkbutton = glade_xml_get_widget (gui, "toolbar_tooltips_checkbutton");
 
-	g_return_val_if_fail (dlg->priv->toolbar_show_radiobutton != NULL, FALSE);
-	g_return_val_if_fail (dlg->priv->toolbar_hide_radiobutton != NULL, FALSE);
+	g_return_val_if_fail (dlg->priv->toolbar_show_checkbutton != NULL, FALSE);
 	
 	g_return_val_if_fail (dlg->priv->toolbar_button_frame != NULL, FALSE);
 	g_return_val_if_fail (dlg->priv->toolbar_system_radiobutton != NULL, FALSE);
@@ -574,16 +674,11 @@ gedit_preferences_dialog_setup_toolbar_page (GeditPreferencesDialog *dlg, GladeX
 	
 	g_return_val_if_fail (dlg->priv->toolbar_tooltips_checkbutton != NULL, FALSE);
 
-	g_signal_connect (G_OBJECT (dlg->priv->toolbar_show_radiobutton), "toggled", 
-			G_CALLBACK (gedit_preferences_dialog_toolbar_show_radiobutton_toggled), dlg);
+	g_signal_connect (G_OBJECT (dlg->priv->toolbar_show_checkbutton), "toggled", 
+			G_CALLBACK (gedit_preferences_dialog_toolbar_show_checkbutton_toggled), dlg);
 
-
-	if (gedit_settings->toolbar_visible)
-		gtk_toggle_button_set_active (
-			GTK_TOGGLE_BUTTON (dlg->priv->toolbar_show_radiobutton), TRUE);
-	else
-		gtk_toggle_button_set_active (
-			GTK_TOGGLE_BUTTON (dlg->priv->toolbar_hide_radiobutton), TRUE);
+	gtk_toggle_button_set_active (
+		GTK_TOGGLE_BUTTON (dlg->priv->toolbar_show_checkbutton), gedit_settings->toolbar_visible);
 
 	switch (gedit_settings->toolbar_buttons_style)
 	{
@@ -615,7 +710,7 @@ gedit_preferences_dialog_setup_toolbar_page (GeditPreferencesDialog *dlg, GladeX
 }
 
 static void 
-gedit_preferences_dialog_toolbar_show_radiobutton_toggled (GtkToggleButton *show_button,
+gedit_preferences_dialog_toolbar_show_checkbutton_toggled (GtkToggleButton *show_button,
 							 GeditPreferencesDialog *dlg)
 {
 	gedit_debug (DEBUG_PREFS, "");
@@ -632,29 +727,43 @@ gedit_preferences_dialog_toolbar_show_radiobutton_toggled (GtkToggleButton *show
 	}
 }
 
+static void 
+gedit_preferences_dialog_statusbar_show_checkbutton_toggled (GtkToggleButton *show_button,
+							 GeditPreferencesDialog *dlg)
+{
+	gedit_debug (DEBUG_PREFS, "");
+
+	if (gtk_toggle_button_get_active (show_button))
+	{
+		gtk_widget_set_sensitive (dlg->priv->statusbar_cursor_position_checkbutton, TRUE);
+		gtk_widget_set_sensitive (dlg->priv->statusbar_overwrite_mode_checkbutton, TRUE);
+	}
+	else
+	{
+		gtk_widget_set_sensitive (dlg->priv->statusbar_cursor_position_checkbutton, FALSE);
+		gtk_widget_set_sensitive (dlg->priv->statusbar_overwrite_mode_checkbutton, FALSE);
+	}
+}
+
+
 static gboolean 
 gedit_preferences_dialog_setup_statusbar_page (GeditPreferencesDialog *dlg, GladeXML *gui)
 {
 	gedit_debug (DEBUG_PREFS, "");
 
-	dlg->priv->statusbar_show_radiobutton = glade_xml_get_widget (gui, "statusbar_show_radiobutton");
-	dlg->priv->statusbar_hide_radiobutton = glade_xml_get_widget (gui, "statusbar_hide_radiobutton");
+	dlg->priv->statusbar_show_checkbutton = glade_xml_get_widget (gui, "statusbar_show_checkbutton");
 	dlg->priv->statusbar_cursor_position_checkbutton = glade_xml_get_widget (gui, 
 								"statusbar_cursor_position_checkbutton");
 	dlg->priv->statusbar_overwrite_mode_checkbutton = glade_xml_get_widget (gui, 
 								"statusbar_overwrite_mode_checkbutton");
 
-	g_return_val_if_fail (dlg->priv->statusbar_show_radiobutton, FALSE);
-	g_return_val_if_fail (dlg->priv->statusbar_hide_radiobutton, FALSE);
+	g_return_val_if_fail (dlg->priv->statusbar_show_checkbutton, FALSE);
 	g_return_val_if_fail (dlg->priv->statusbar_cursor_position_checkbutton, FALSE);
 	g_return_val_if_fail (dlg->priv->statusbar_overwrite_mode_checkbutton, FALSE);
 	
-	if (gedit_settings->statusbar_visible)
-		gtk_toggle_button_set_active (
-				GTK_TOGGLE_BUTTON (dlg->priv->statusbar_show_radiobutton), TRUE);
-	else
-		gtk_toggle_button_set_active (
-				GTK_TOGGLE_BUTTON (dlg->priv->statusbar_hide_radiobutton), TRUE);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (
+				      dlg->priv->statusbar_show_checkbutton), 
+				      gedit_settings->statusbar_visible);
 
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (
 				      dlg->priv->statusbar_cursor_position_checkbutton),	
@@ -663,9 +772,19 @@ gedit_preferences_dialog_setup_statusbar_page (GeditPreferencesDialog *dlg, Glad
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (
 				      dlg->priv->statusbar_overwrite_mode_checkbutton),
 				      gedit_settings->statusbar_view_overwrite_mode);
+
+	if (!gedit_settings->statusbar_visible)
+	{
+		gtk_widget_set_sensitive (dlg->priv->statusbar_cursor_position_checkbutton, FALSE);
+		gtk_widget_set_sensitive (dlg->priv->statusbar_overwrite_mode_checkbutton, FALSE);
+	}
+
+	g_signal_connect (G_OBJECT (dlg->priv->statusbar_show_checkbutton), "toggled", 
+			G_CALLBACK (gedit_preferences_dialog_statusbar_show_checkbutton_toggled), dlg);
+
 	return TRUE;
 }
-
+#endif
 #ifdef DEBUG_MDI_PREFS
 
 static void
@@ -933,6 +1052,19 @@ gedit_preferences_dialog_setup_wrap_mode_page (GeditPreferencesDialog *dlg, Glad
 	return TRUE;
 }
 
+static void
+gedit_preferences_dialog_auto_save_checkbutton_toggled (GtkToggleButton *button,
+							 GeditPreferencesDialog *dlg)
+{
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dlg->priv->auto_save_checkbutton)))
+	{
+		gtk_widget_set_sensitive (dlg->priv->auto_save_spinbutton, TRUE);
+		gtk_widget_grab_focus (dlg->priv->auto_save_spinbutton);
+	}
+	else	
+		gtk_widget_set_sensitive (dlg->priv->auto_save_spinbutton, FALSE);
+}
+
 static gboolean 
 gedit_preferences_dialog_setup_save_page (GeditPreferencesDialog *dlg, GladeXML *gui)
 {
@@ -962,7 +1094,10 @@ gedit_preferences_dialog_setup_save_page (GeditPreferencesDialog *dlg, GladeXML
 
 	/* FIXME */
 	gtk_widget_set_sensitive (dlg->priv->locale_if_previous_radiobutton, FALSE);
-	
+
+	g_signal_connect (G_OBJECT (dlg->priv->auto_save_checkbutton), "toggled", 
+			G_CALLBACK (gedit_preferences_dialog_auto_save_checkbutton_toggled), dlg);
+
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dlg->priv->backup_copy_checkbutton),
 				      gedit_settings->create_backup_copy);
 
@@ -970,7 +1105,7 @@ gedit_preferences_dialog_setup_save_page (GeditPreferencesDialog *dlg, GladeXML
 				      gedit_settings->auto_save);
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (dlg->priv->auto_save_spinbutton),
 				    gedit_settings->auto_save_interval);
-
+	gtk_widget_set_sensitive (dlg->priv->auto_save_spinbutton, gedit_settings->auto_save);
 
 	switch (gedit_settings->save_encoding)
 	{
@@ -1053,6 +1188,127 @@ gedit_preferences_dialog_setup_page_page (GeditPreferencesDialog *dlg, GladeXML
 	return TRUE;
 }
 
+static void
+gedit_preferences_dialog_print_font_restore_default_button_clicked (
+		GtkButton *button, GeditPreferencesDialog *dlg)
+{
+	g_return_if_fail (dlg->priv->body_fontpicker != NULL);
+	g_return_if_fail (dlg->priv->headers_fontpicker != NULL);
+	g_return_if_fail (dlg->priv->numbers_fontpicker != NULL);
+
+	/* FIXME: define constants, or take them from schemas */
+	gnome_print_font_picker_set_font_name (
+			GNOME_PRINT_FONT_PICKER (dlg->priv->body_fontpicker),
+			"Courier 9");
+
+	gnome_print_font_picker_set_font_name (
+			GNOME_PRINT_FONT_PICKER (dlg->priv->headers_fontpicker),
+			"Helvetica 11");
+
+	gnome_print_font_picker_set_font_name (
+			GNOME_PRINT_FONT_PICKER (dlg->priv->numbers_fontpicker),
+			"Helvetica 8");
+}
+
+static gboolean 
+gedit_preferences_dialog_setup_print_fonts_page (GeditPreferencesDialog *dlg, GladeXML *gui)
+{	
+	GtkWidget *print_fonts_table;
+	GtkWidget *body_font_label;
+	GtkWidget *headers_font_label;
+	GtkWidget *numbers_font_label;
+
+	gedit_debug (DEBUG_PREFS, "");
+
+	print_fonts_table = glade_xml_get_widget (gui, "print_fonts_table");
+	body_font_label = glade_xml_get_widget (gui, "body_font_label");
+	headers_font_label = glade_xml_get_widget (gui,	"headers_font_label");
+	numbers_font_label = glade_xml_get_widget (gui,	"numbers_font_label");
+	dlg->priv->restore_default_fonts_button = glade_xml_get_widget (gui, 
+ 			"restore_default_fonts_button");
+
+	g_return_val_if_fail (print_fonts_table != NULL, FALSE);
+	g_return_val_if_fail (body_font_label != NULL, FALSE);
+	g_return_val_if_fail (headers_font_label != NULL, FALSE);
+	g_return_val_if_fail (numbers_font_label != NULL, FALSE);
+	g_return_val_if_fail (dlg->priv->restore_default_fonts_button != NULL, FALSE);
+			
+	/* Body font picker */
+	dlg->priv->body_fontpicker = gnome_print_font_picker_new ();
+	gnome_print_font_picker_set_mode (
+			GNOME_PRINT_FONT_PICKER (dlg->priv->body_fontpicker), 
+			GNOME_PRINT_FONT_PICKER_MODE_FONT_INFO);
+	
+	gnome_print_font_picker_fi_set_show_size (
+			GNOME_PRINT_FONT_PICKER (dlg->priv->body_fontpicker), TRUE);
+
+	gnome_print_font_picker_fi_set_use_font_in_label (
+			GNOME_PRINT_FONT_PICKER (dlg->priv->body_fontpicker), TRUE, 14);
+
+	gtk_table_attach_defaults (GTK_TABLE (print_fonts_table), 
+			dlg->priv->body_fontpicker, 1, 2, 0, 1);
+	
+	/* Headers font picker */
+	dlg->priv->headers_fontpicker = gnome_print_font_picker_new ();
+	gnome_print_font_picker_set_mode (
+			GNOME_PRINT_FONT_PICKER (dlg->priv->headers_fontpicker), 
+			GNOME_PRINT_FONT_PICKER_MODE_FONT_INFO);
+	
+	gnome_print_font_picker_fi_set_show_size (
+			GNOME_PRINT_FONT_PICKER (dlg->priv->headers_fontpicker), TRUE);
+	
+	gnome_print_font_picker_fi_set_use_font_in_label (
+			GNOME_PRINT_FONT_PICKER (dlg->priv->headers_fontpicker), TRUE, 14);
+
+	gtk_table_attach_defaults (GTK_TABLE (print_fonts_table), 
+			dlg->priv->headers_fontpicker, 1, 2, 1, 2);
+
+	/* Numbers font picker */
+	dlg->priv->numbers_fontpicker = gnome_print_font_picker_new ();
+	gnome_print_font_picker_set_mode (
+			GNOME_PRINT_FONT_PICKER (dlg->priv->numbers_fontpicker), 
+			GNOME_PRINT_FONT_PICKER_MODE_FONT_INFO);
+	
+	gnome_print_font_picker_fi_set_show_size (
+			GNOME_PRINT_FONT_PICKER (dlg->priv->numbers_fontpicker), TRUE);
+	
+	gnome_print_font_picker_fi_set_use_font_in_label (
+			GNOME_PRINT_FONT_PICKER (dlg->priv->numbers_fontpicker), TRUE, 14);
+
+	gtk_table_attach_defaults (GTK_TABLE (print_fonts_table), 
+			dlg->priv->numbers_fontpicker, 1, 2, 2, 3);
+
+	gtk_label_set_mnemonic_widget (GTK_LABEL (body_font_label), 
+				       dlg->priv->body_fontpicker);
+	
+	gtk_label_set_mnemonic_widget (GTK_LABEL (headers_font_label), 
+				       dlg->priv->headers_fontpicker);
+
+	gtk_label_set_mnemonic_widget (GTK_LABEL (numbers_font_label), 
+				       dlg->priv->numbers_fontpicker);
+
+	if (gedit_settings->print_font_body)
+		gnome_print_font_picker_set_font_name (
+				GNOME_PRINT_FONT_PICKER (dlg->priv->body_fontpicker),
+						 gedit_settings->print_font_body);
+
+	if (gedit_settings->print_font_header)
+		gnome_print_font_picker_set_font_name (
+				GNOME_PRINT_FONT_PICKER (dlg->priv->headers_fontpicker),
+						 gedit_settings->print_font_header);
+
+	if (gedit_settings->print_font_numbers)
+		gnome_print_font_picker_set_font_name (
+				GNOME_PRINT_FONT_PICKER (dlg->priv->numbers_fontpicker),
+						 gedit_settings->print_font_numbers);
+
+	g_signal_connect (G_OBJECT (dlg->priv->restore_default_fonts_button), "clicked",
+			  G_CALLBACK (gedit_preferences_dialog_print_font_restore_default_button_clicked),
+			  dlg);
+
+	return TRUE;
+}
+
 static gboolean 
 gedit_preferences_dialog_setup_line_numbers_page (GeditPreferencesDialog *dlg, GladeXML *gui)
 {
@@ -1072,16 +1328,17 @@ gedit_preferences_dialog_setup_line_numbers_page (GeditPreferencesDialog *dlg, G
 gboolean 
 gedit_preferences_dialog_update_settings (GeditPreferencesDialog *dlg)
 {
+#if 0
 	GeditPreferences old_prefs;
+#endif
 	const gchar* font;
 	guint16 dummy;
 
 	gedit_debug (DEBUG_PREFS, "");
-	
+#if 0		
 	old_prefs = *gedit_settings;
-	
 	/* Get data from toolbar page */
-	if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dlg->priv->toolbar_show_radiobutton)))
+	if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dlg->priv->toolbar_show_checkbutton)))
 		gedit_settings->toolbar_visible = FALSE;
 	else
 	{
@@ -1105,10 +1362,9 @@ gedit_preferences_dialog_update_settings (GeditPreferencesDialog *dlg)
 	}
 
 	/* Get data from status bar page */
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dlg->priv->statusbar_show_radiobutton)))
-		gedit_settings->statusbar_visible = TRUE;
-	else
-		gedit_settings->statusbar_visible = FALSE;
+	gedit_settings->statusbar_visible =
+		gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (
+					dlg->priv->statusbar_show_checkbutton));
 
 	gedit_settings->statusbar_view_cursor_position = 
 		gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (
@@ -1117,7 +1373,7 @@ gedit_preferences_dialog_update_settings (GeditPreferencesDialog *dlg)
 	gedit_settings->statusbar_view_overwrite_mode = 
 		gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (
 					dlg->priv->statusbar_overwrite_mode_checkbutton));
-		
+#endif		
 	/* Get data from undo page */
 	if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dlg->priv->undo_checkbutton)))
 		gedit_settings->undo_levels = 0;
@@ -1241,11 +1497,37 @@ gedit_preferences_dialog_update_settings (GeditPreferencesDialog *dlg)
 	gedit_settings->tab_size =
 		gtk_spin_button_get_value (GTK_SPIN_BUTTON (dlg->priv->tabs_width_spinbutton));
 
+	/* Print/fonts page */
+	font = gnome_print_font_picker_get_font_name (
+			GNOME_PRINT_FONT_PICKER (dlg->priv->body_fontpicker));		
+	if (font != NULL)
+	{
+		g_free (gedit_settings->print_font_body);
+		gedit_settings->print_font_body = g_strdup (font);
+	}
+
+	font = gnome_print_font_picker_get_font_name (
+			GNOME_PRINT_FONT_PICKER (dlg->priv->headers_fontpicker));		
+	if (font != NULL)
+	{
+		g_free (gedit_settings->print_font_header);
+		gedit_settings->print_font_header = g_strdup (font);
+	}
+
+	font = gnome_print_font_picker_get_font_name (
+			GNOME_PRINT_FONT_PICKER (dlg->priv->numbers_fontpicker));		
+	if (font != NULL)
+	{
+		g_free (gedit_settings->print_font_numbers);
+		gedit_settings->print_font_numbers = g_strdup (font);
+	}
+
 	return TRUE;
-	
+#if 0	
 error:
 	*gedit_settings = old_prefs;
 	g_return_val_if_fail (FALSE, FALSE);
+#endif
 }
 
 	
